@@ -86,7 +86,7 @@ void gripe_replace_key (const char *data)
 	gripe_corrupt_data ();
 }
 
-char *copy_if_set (const char *str)
+static char *copy_if_set (const char *str)
 {
 	if (STREQ (str, "-"))
 		return NULL;
@@ -110,13 +110,13 @@ void dbprintf (const struct mandata *info)
 	       "section:   %s\n"
 	       "comp. ext: %s\n"
 	       "id:        %c\n"
-	       "st_mtime   %ld\n"
+	       "mtime:     %ld.%09ld\n"
 	       "pointer:   %s\n"
 	       "filter:    %s\n"
 	       "whatis:    %s\n\n",
 	       dash_if_unset (info->name),
 	       info->ext, info->sec, info->comp,
-	       info->id, (long) info->_st_mtime,
+	       info->id, (long) info->mtime.tv_sec, info->mtime.tv_nsec,
 	       info->pointer, info->filter, info->whatis);
 }
 
@@ -170,7 +170,7 @@ char *name_to_key (const char *name)
 }
 
 /* return char ptr array to the data's fields */
-char **split_data (char *content, char *start[])
+static char **split_data (char *content, char *start[])
 {
         int count;
 
@@ -210,7 +210,8 @@ void split_content (char *cont_ptr, struct mandata *pinfo)
 	pinfo->name = copy_if_set (*(data++));
 	pinfo->ext = *(data++);
 	pinfo->sec = *(data++);
-	pinfo->_st_mtime = (time_t) atol (*(data++));	/* time_t format */
+	pinfo->mtime.tv_sec = (time_t) atol (*(data++));
+	pinfo->mtime.tv_nsec = atol (*(data++));
 	pinfo->id = **(data++);				/* single char id */
 	pinfo->pointer = *(data++);
 	pinfo->filter = *(data++);
@@ -221,45 +222,6 @@ void split_content (char *cont_ptr, struct mandata *pinfo)
 	pinfo->next = (struct mandata *) NULL;
 }
 
-/* The complement of split_content */
-datum make_content (struct mandata *in)
-{
-	datum cont;
-	static const char dash[] = "-";
-
-	memset (&cont, 0, sizeof cont);
-
-	if (!in->pointer)
-		in->pointer = dash;
-	if (!in->filter)
-		in->filter = dash;
-	if (!in->comp)
-		in->comp = dash;
-	if (!in->whatis)
-		in->whatis = dash + 1;
-
-	MYDBM_SET (cont, xasprintf (
-		"%s\t%s\t%s\t%ld\t%c\t%s\t%s\t%s\t%s",
-		dash_if_unset (in->name),
-		in->ext,
-		in->sec,
-		(long) in->_st_mtime,
-		in->id,
-		in->pointer,
-		in->filter,
-		in->comp,
-		in->whatis));
-
-#ifdef NDBM
-	/* limit of 4096 bytes of data using ndbm */
-	if (MYDBM_DSIZE (cont) > 4095) {
-		MYDBM_DPTR (cont)[4095] = '\0';
-		MYDBM_DSIZE (cont) = 4096;
-	}
-#endif
-	return cont;
-}
-
 /* Extract all of the names/extensions associated with this key. Each case
  * variant of a name will be returned separately.
  *
@@ -304,7 +266,6 @@ int list_extensions (char *data, char ***names, char ***ext)
  2) One data item exists. Item is returned as first in set of structures.
  3) Many items exist. They are all returned, in a multiple structure set.
  */
-#ifndef FAST_BTREE
 static struct mandata *dblookup (const char *page, const char *section,
 				 int flags)
 {
@@ -403,7 +364,6 @@ static struct mandata *dblookup (const char *page, const char *section,
 		return ret;
 	}
 }
-#endif /* !FAST_BTREE */
 
 struct mandata *dblookup_all (const char *page, const char *section,
 			      int match_case)
