@@ -40,22 +40,7 @@
 #include <sys/stat.h>
 #include <errno.h>
 #include <assert.h>
-
-#ifdef HAVE_DIRENT_H
-#  include <dirent.h>
-#else /* not HAVE_DIRENT_H */
-#  define dirent direct
-#  ifdef HAVE_SYS_NDIR_H
-#    include <sys/ndir.h>
-#  endif /* HAVE_SYS_NDIR_H */
-#  ifdef HAVE_SYS_DIR_H
-#    include <sys/dir.h>
-#  endif /* HAVE_SYS_DIR_H */
-#  ifdef HAVE_NDIR_H
-#    include <ndir.h>
-#  endif /* HAVE_NDIR_H */
-#endif /* HAVE_DIRENT_H  */
-
+#include <dirent.h>
 #include <unistd.h>
 
 #include "canonicalize.h"
@@ -243,8 +228,8 @@ static void ult_trace (struct ult_trace *trace, const char *s)
 		return;
 	if (trace->len >= trace->max) {
 		trace->max *= 2;
-		trace->names = xrealloc (trace->names,
-					 sizeof (char *) * trace->max);
+		trace->names = xnrealloc (trace->names, trace->max,
+					  sizeof (char *));
 	}
 	trace->names[trace->len++] = xstrdup (s);
 }
